# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["HangupToolParamsParam"]


class HangupToolParamsParam(TypedDict, total=False):
    description: str
    """The description of the function that will be passed to the assistant."""
